@@ -32,24 +32,56 @@ respective ACME resource:
 
 =back
 
-=head1 EXAMPLES
-
-See the C<examples> directory in the distribution.
-
 =head1 WHY USE THIS MODULE?
 
 =over 4
 
-=item * Well-defined object system, including typed exceptions.
+=item * Closely based on cPanel’s widely used Let’s Encrypt plugin.
 
-=item * Based on cPanel’s widely used Let’s Encrypt plugin.
+=item * Thorough error-checking: any deviation from what the ACME protocol
+expects is reported immediately via an exception.
+
+=item * Well-defined object system, including typed, queryable exceptions.
+
+=item * Extensive test coverage.
+
+=item * Light memory footprint - no Moose/Moo/etc.
 
 =item * Only one non-core, non-pure-Perl dependency (L<Crypt::OpenSSL::RSA>),
 and there’s a fallback to the system C<openssl> binary if that module isn’t
-available.
+available. Net::ACME should run almost anywhere!
 
 =back
 
+=head1 STATUS
+
+This module is now well-tested and should be safe for use in your application.
+
+=head1 CUSTOMIZATION
+
+B<OpenSSL>: This module will attempt to use L<Crypt::OpenSSL::RSA> if it is
+available; if not, it falls back to the C<openssl> binary. On most systems this
+should already be in the process’s search path, but if not, specify the binary’s
+location by setting C<$Net::ACME::Crypt::OPENSSL_BIN_PATH>.
+
+B<HTTPS options>: This module uses C<HTTP::Tiny> for its network operations.
+In some instances it is desirable to specify custom C<SSL_options> in that
+module’s constructor; to do this, populate
+C<@Net::ACME::HTTP_Tiny::SSL_OPTIONS>.
+
+=head1 URI vs. URL
+
+This module uses “uri” for ACME-related objects and “url” for
+HTTP-related ones. This apparent conflict is a result of maintaining
+consistency with both the ACME specification (“uri”) and L<HTTP::Tiny> (“url”).
+
+=head1 EXAMPLES
+
+See the C<examples> directory in the distribution for complete, interactive
+example scripts that also illustrate a bit of how ACME works.
+
+See below for cut-paste-y examples.
+
 =head1 EXAMPLE: REGISTRATION
 
     my $tos_url = Net::ACME::LetsEncrypt->get_terms_of_service();
@@ -73,16 +105,20 @@ available.
             #accept as proof of domain control. As of November 2016, these
             #sets all contain exactly one challenge each: “http-01”, etc.
 
+            #Each member of @$cmb_ar is an instance of
+            #Net::ACME::Challenge::Pending--maybe a subclass thereof such as
+            #Net::ACME::Challenge::Pending::http_01.
+
             #At this point, you examine $cmb_ar and determine if this
             #combination is one that you’re interested in. You might try
             #something like:
             #
             #   next if @$cmb_ar > 1;
-            #   next if $cmb_ar->[0]{'type'} ne 'http-01';
+            #   next if $cmb_ar->[0]->type() ne 'http-01';
 
-            #Once you’ve examined $cmb_ar and set up the appropriate response,
+            #Once you’ve examined $cmb_ar and set up the appropriate response(s),
             #it’s time to tell the ACME server to send its challenge query.
-            $acme->do_challenge($_) for @challenges;
+            $acme->do_challenge($_) for @$cmb_ar;
 
             while (1) {
                 if ( $authz_p->is_time_to_poll() ) {
@@ -122,14 +158,11 @@ available.
 
 =over 4
 
-=item * Improve documentation
-
-=item * Port tests from original cPanel module. (The meaningful ones are highly
-dependent on cPanel’s testing framework.)
+=item * Find a way to sign with RSA in pure Perl.
 
 =item * Support EC keys.
 
-=item * Test and support ACME v2 features (pending server support).
+=item * Test and support more ACME v2 features (pending server support).
 
 =back
 
@@ -159,7 +192,7 @@ I am aware of the following additional CPAN modules that implement this protocol
 
 =back
 
-=head1 REPOSITORY
+=head1 REPOSITORY (FEEDBACK/BUGS)
 
 L<https://github.com/FGasper/p5-Net-ACME>
 
@@ -190,9 +223,6 @@ use Net::ACME::X                           ();
 our $VERSION;
 *VERSION = \$Net::ACME::Constants::VERSION;
 
-#https://rt.cpan.org/Ticket/Display.html?id=114027
-our $_ACCOMMODATE_RT114027 = 0;
-
 *_to_base64url = \&MIME::Base64::encode_base64url;
 
 sub new {
@@ -223,9 +253,7 @@ sub accept_tos {
         },
     );
 
-    if ( !$_ACCOMMODATE_RT114027 ) {
-        $resp->die_because_unexpected() if $resp->status() != 202;
-    }
+    $resp->die_because_unexpected() if $resp->status() != 202;
 
     return;
 }
@@ -247,7 +275,7 @@ sub register {
 
     $resp = $self->_post( 'new-reg', $payload );
 
-    if ( !$_ACCOMMODATE_RT114027 && $resp->status() != 201 ) {
+    if ( $resp->status() != 201 ) {
         $resp->die_because_unexpected();
     }
 
@@ -320,18 +348,10 @@ sub start_domain_authz {
         },
     );
 
-    if ( !$_ACCOMMODATE_RT114027 ) {
-        $resp->die_because_unexpected() if $resp->status() != 201;
-    }
+    $resp->die_because_unexpected() if $resp->status() != 201;
 
     my $content = $resp->content_struct();
 
-    #my $http_challenge_index = _get_http_challenge_index($content);
-    #
-    #_validate_combinations_for_http_only( $content, $http_challenge_index );
-    #
-    #my $http_challenge_hr = $content->{'challenges'}[$http_challenge_index];
-
     return Net::ACME::Authorization::Pending->new(
         uri          => $resp->header('location'),
         combinations => $content->{'combinations'},
@@ -466,58 +486,6 @@ sub _set_ua {
     return;
 }
 
-#Find the challenge index for HTTP
-sub _get_http_challenge_index {
-    my ($content) = @_;
-
-    my $http_challenge_index;
-
-    #For now, we do this simply by just hard-coding logic
-    #that only does one http-01 challenge.
-    my @challenges = @{ $content->{'challenges'} };
-    for ( 0 .. $#challenges ) {
-        if ( $challenges[$_]->{'type'} eq 'http-01' ) {
-            $http_challenge_index = $_;
-            last;
-        }
-    }
-
-    #This probably indicates an error in server configuration more than anything.
-    if ( !defined $http_challenge_index ) {
-        die Net::ACME::X->new( sprintf "This authorization does not accept [asis,HTTP] validation! (%s)", JSON::encode_json($content) );
-    }
-
-    return $http_challenge_index;
-}
-
-sub _validate_combinations_for_http_only {
-    my ( $content, $http_challenge_index ) = @_;
-
-    my $http_is_enough = ( @{ $content->{'challenges'} } == 1 );
-
-    if ( !$http_is_enough ) {
-
-        #Find a combination that consists exclusively of the number that
-        #corresponds to the HTTP challenge.
-        #NB: Per the ACME spec, no combinations means all challenges are required.
-        if ( $content->{'combinations'} ) {
-            for ( @{ $content->{'combinations'} } ) {
-                if ( "@$_" == $http_challenge_index ) {
-                    $http_is_enough = 1;
-                    last;
-                }
-            }
-        }
-    }
-
-    #This probably indicates an error in server configuration more than anything.
-    if ( !$http_is_enough ) {
-        die Net::ACME::X->new( sprintf "This authorization requires more than [asis,HTTP] validation! (%s)", JSON::encode_json($content) );
-    }
-
-    return;
-}
-
 #TODO: cache
 sub _get_directory {
     my ($self) = @_;
