@@ -25,22 +25,27 @@ use parent qw( Net::ACME::X::HashBase );
 
 # In a normal HTTP response, we don't necessarily know if the body is going
 # to be meaningful for display, so only include the first chunk.
-my $BODY_DISPLAY_SIZE = 1_024;
+#
+#(accessed from tests)
+use constant BODY_DISPLAY_SIZE => 1_024;
 
 #named args required:
 #
-#   error
 #   method
+#   reason
 #   url
+#   status
 #
 sub new {
     my ( $self, $args_hr ) = @_;
 
     my $content = $args_hr->{'content'};
-    if ( length($content) > $BODY_DISPLAY_SIZE ) {
-        substr( $content, $BODY_DISPLAY_SIZE ) = '…';
+    if ( length($content) && length($content) > BODY_DISPLAY_SIZE() ) {
+        substr( $content, BODY_DISPLAY_SIZE() ) = '…';
     }
 
+    $content ||= q<>;
+
     return $self->SUPER::new(
         "The response to the HTTP “$args_hr->{'method'}” request from “$args_hr->{'url'}” indicated an error ($args_hr->{'status'}, $args_hr->{'reason'}): “$content”",
         $args_hr,
